@@ -3,6 +3,7 @@ from joonmyung.utils import to_np
 import wandb
 import torch
 import os
+import re
 
 class AverageMeter:
     ''' Computes and stores the average and current value. '''
@@ -41,14 +42,16 @@ class AverageMeter:
 class Logger():
     loggers = {}
     def __init__(self, use_wandb=True, wandb_entity=None, wandb_project=None, wandb_name=None
-                 , wandb_watch=False, main_process=False
+                 , wandb_watch=False, main_process=True, wandb_id=None
                  , args=None, model=False
                  , save=True):
         self.use_wandb = use_wandb and main_process
 
         if self.use_wandb:
-            wandb.init(entity=wandb_entity, project=wandb_project, name=wandb_name, resume="allow",
-                       config=args)
+            if not wandb_id: wandb_id = re.sub('[^A-Za-z0-9]+', '', str(args))
+
+            wandb.init(entity=wandb_entity, project=wandb_project, name=wandb_name, resume="True",
+                       config=args, id = wandb_id)
             if wandb_watch and model: wandb.watch(model, log='all')
             if save and args: torch.save({'args': args, }, os.path.join(wandb.run.dir, "args.pt"))
 
@@ -98,21 +101,23 @@ class Logger():
         wandb.finish()
 
 if __name__ == "__main__":
-    from playground.analysis.utils.dataset import JDataset
-    root_path = "/hub_data/joonmyung/data"
-    dataset, num_classes, epoch = "cifar100", 10, 1
+    from playground.analysis.lib_import import *
+    dataset_name, server, device = "imagenet", "148", "cuda"
+    data_path, _ = data2path(server, dataset_name)
     data_num = [[5, 1],
                 [5, 2],
                 [5, 3],
                 [5, 4]]
-    dataset = JDataset(root_path, dataset)
-    inputs, targets, imgs, label_names = dataset.getitems(data_num)
+    dataset = JDataset(data_path, dataset_name, device=device)
+    samples, targets, imgs, label_names = dataset.getItems(data_num)
 
-    logger = Logger(use_wandb=True, wandb_entity="joonmyung", wandb_project="test", wandb_name="LOGGGG",
+    logger = Logger(use_wandb=True, wandb_entity="joonmyung", wandb_project="test", wandb_name="AAPP", wandb_id="ABCD",
                     wandb_watch=False)
 
-    logger.addLog({ "sample A": [0, 1],
-                    "sample B": [0, 2],
-                    "sample C": [0, 3],
-                    "table  B": [2, {"image" :     inputs, "prediction": targets}]})
-    logger.logWandb()
\ No newline at end of file
+    logger.addLog({ "sample A": [0, 4],
+                    "sample B": [0, 3],
+                    "sample C": [0, 2],
+                    "table  B": [2, {"image" :     samples, "prediction": targets}]})
+    logger.logWandb()
+
+    logger.finish()
\ No newline at end of file
